summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp b/lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp
index 063c76ba..63a860e7 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp
@@ -75,11 +75,11 @@ void KMdiChildArea::manageChild( KMdiChildFrm* child, bool show, bool cascade )
KMdiChildFrm* top = topChild();
//remove old references. There can be more than one so we remove them all
- if ( m_pZ->tqfindRef( child ) != -1 )
+ if ( m_pZ->findRef( child ) != -1 )
{
//TQPtrList::tqfind* moves current() to the found item
m_pZ->take();
- while ( m_pZ->tqfindNextRef( child ) != -1 )
+ while ( m_pZ->findNextRef( child ) != -1 )
m_pZ->take();
}
@@ -323,7 +323,7 @@ TQPoint KMdiChildArea::getCascadePoint( int indexOfWindow )
void KMdiChildArea::childMinimized( KMdiChildFrm *minimizedChild, bool wasMaximized )
{
//can't find the child in our list, so we don't care.
- if ( m_pZ->tqfindRef( minimizedChild ) == -1 )
+ if ( m_pZ->findRef( minimizedChild ) == -1 )
{
kdDebug( 760 ) << k_funcinfo << "child was minimized but wasn't in our list!" << endl;
return;
@@ -790,4 +790,4 @@ void KMdiChildArea::getCaptionColors( const TQPalette& /*pal*/, TQColor& activeB
inactiveFG = KGlobalSettings::inactiveTextColor();
}
-// kate: space-indent off; tqreplace-tabs off; tab-width 4; indent-mode csands;
+// kate: space-indent off; replace-tabs off; tab-width 4; indent-mode csands;
@@ -75,11 +75,11 @@ void KMdiChildArea::manageChild( KMdiChildFrm* child, bool show, bool cascade )
{
- //TQPtrList::tqfind* moves current() to the found item
+ //TQPtrList::find* moves current() to the found item
m_pZ->take();